/***************************************************************************
 *           GCTAInstDir.i  -  CTA instrument direction class              *
 * ----------------------------------------------------------------------- *
 *  copyright (C) 2010-2011 by Jurgen Knodlseder                           *
 * ----------------------------------------------------------------------- *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
/**
 * @file GCTAInstDir.i
 * @brief CTA instrument direction class Python interface definition
 * @author J. Knodlseder
 */
%{
/* Put headers and other declarations here that are needed for compilation */
#include "GCTAInstDir.hpp"
%}


/***********************************************************************//**
 * @class GCTAInstDir
 *
 * @brief CTA instrument direction class
 ***************************************************************************/
class GCTAInstDir : public GInstDir {

public:
    // Constructors and destructors
    GCTAInstDir(void);
    GCTAInstDir(const GCTAInstDir& dir);
    virtual ~GCTAInstDir(void);

    // Methods
    void         clear(void);
    GCTAInstDir* clone(void) const;
    void         skydir(const GSkyDir& dir);
    void         radec(const double& ra, const double& dec);
    void         radec_deg(const double& ra, const double& dec);
    void         lb(const double& l, const double& b);
    void         lb_deg(const double& l, const double& b);
    void         rotate_deg(const double& phi, const double& theta);
    GSkyDir      skydir(void) const;
    double       l(void) const;
    double       l_deg(void) const;
    double       b(void) const;
    double       b_deg(void) const;
    double       ra(void) const;
    double       ra_deg(void) const;
    double       dec(void) const;
    double       dec_deg(void) const;
    double       dist(GSkyDir& dir) const;
    double       dist_deg(GSkyDir& dir) const;
    double       dist(GCTAInstDir& dir) const;
    double       dist_deg(GCTAInstDir& dir) const;
    double       posang(const GSkyDir& dir) const;
    double       posang_deg(const GSkyDir& dir) const;
    double       posang(const GCTAInstDir& dir) const;
    double       posang_deg(const GCTAInstDir& dir) const;
};


/***********************************************************************//**
 * @brief GCTAInstDir class extension
 ***************************************************************************/
%extend GCTAInstDir {
    GCTAInstDir copy() {
        return (*self);
    }
};


/***********************************************************************//**
 * @brief GCTAInstDir type casts
 ***************************************************************************/
%inline %{
    GCTAInstDir* cast_GCTAInstDir(GInstDir* arg) {
        GCTAInstDir* dir = dynamic_cast<GCTAInstDir*>(arg);
        if (dir == NULL)
            throw GException::bad_type("cast_GCTAInstDir(GInstDir*)",
                                       "GInstDir not of type GCTAInstDir");
        return dir;
    }
%}
