/***************************************************************************
 *               GLATObservation.i  -  LAT Observation class               *
 * ----------------------------------------------------------------------- *
 *  copyright : (C) 2008-2011 by Jurgen Knodlseder                         *
 * ----------------------------------------------------------------------- *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
/**
 * @file GLATObservation.i
 * @brief LAT Observation class Python interface definition
 * @author J. Knodlseder
 */
%{
/* Put headers and other declarations here that are needed for compilation */
#include "GLATObservation.hpp"
%}
%include stl.i

/***********************************************************************//**
 * @class GLATObservation
 *
 * @brief LAT Observation class Python interface
 ***************************************************************************/
class GLATObservation : public GObservation {
public:
    // Constructors and destructors
    GLATObservation();
    GLATObservation(const GLATObservation& obs);
    virtual ~GLATObservation();

    // Implemented pure virtual base class methods
    virtual void             clear(void);
    virtual GLATObservation* clone(void) const;
    virtual GLATResponse*    response(void) const;
    virtual GLATPointing*    pointing(const GTime& time) const;
    virtual std::string      instrument(void) const;

    // Other methods
    void                     load_unbinned(const std::string& ft1name,
                                           const std::string& ft2name,
                                           const std::string& ltcube_name);
    void                     load_binned(const std::string& cntmap_name,
                                         const std::string& expmap_name,
                                         const std::string& ltcube_name);
    void                     response(const std::string& irfname,
                                      std::string caldb = "");    
    GLATLtCube*              ltcube(void) const;
};


/***********************************************************************//**
 * @brief GLATObservation class extension
 ***************************************************************************/
%extend GLATObservation {
    GLATObservation copy() {
        return (*self);
    }
};


/***********************************************************************//**
 * @brief GLATObservation type casts
 ***************************************************************************/
%inline %{
    GLATObservation* cast_GLATObservation(GObservation* obs) {
        GLATObservation* lat = dynamic_cast<GLATObservation*>(obs);
        if (lat == NULL)
            throw GException::bad_type("cast_GLATObservation(GObservation* obs)",
                                       "GObservation not of type GLATObservation");            
        return lat;
    }
%}
